@@ -1,12 +1,7 @@
 package Filter::decrypt ;
 
-require 5.002 ;
 require DynaLoader;
-use strict;
-use warnings;
-use vars qw(@ISA $VERSION);
 @ISA = qw(DynaLoader);
-$VERSION = "1.57" ;
 
 bootstrap Filter::decrypt ;
 1;
@@ -34,14 +29,10 @@ a proper decryption algorithm to develop your own decryption filter.
 It is important to note that a decryption filter can I<never> provide
 complete security against attack. At some point the parser within Perl
 needs to be able to scan the original decrypted source. That means that
-at some stage fragments of the source will exist in a memory buffer. 
-
-Also, with the introduction of the Perl Compiler backend modules, and
-the B::Deparse module in particular, using a Source Filter to hide source
-code is becoming an increasingly futile exercise.
+at some stage fragments of the source will exist in a memory buffer.
 
 The best you can hope to achieve by decrypting your Perl source using a
-source filter is to make it unavailable to the casual user.
+source filter is to make it impractical to crack.
 
 Given that proviso, there are a number of things you can do to make
 life more difficult for the prospective cracker.
@@ -61,7 +52,7 @@ linking it at run time with a modified Perl binary.
 =item 3.
 
 Do not build Perl with C<-DDEBUGGING>. If you do then your source can
-be retrieved with the C<-DP> command line option. 
+be retrieved with the C<-Dp> command line option. 
 
 The sample filter contains logic to detect the C<DEBUGGING> option.
 
@@ -77,24 +68,6 @@ the sub-process.
 
 =item 6.
 
-Check that the Perl Compiler isn't being used. 
-
-There is code in the BOOT: section of decrypt.xs that shows how to detect
-the presence of the Compiler. Make sure you include it in your module.
-
-Assuming you haven't taken any steps to spot when the compiler is in
-use and you have an encrypted Perl script called "myscript.pl", you can
-get access the source code inside it using the perl Compiler backend,
-like this
-
-    perl -MO=Deparse myscript.pl
-
-Note that even if you have included the BOOT: test, it is still
-possible to use the Deparse module to get the source code for individual
-subroutines.
-
-=item 7.
-
 Do not use the decrypt filter as-is. The algorithm used in this filter
 has been purposefully left simple.
 
@@ -110,6 +83,6 @@ Paul Marquess
 
 =head1 DATE
 
-19th December 1995
+20th November 1995
 
 =cut
